# -*- coding: iso-8859-15 -*-

import os
import platform

from ogzCalendar import ogzCalendar
from ogzCategorie import ogzCategorie

class ogzConfig:
    def __init__(self, oBase):
        self.oBase = oBase
        self.configFile = "ngcal.conf"
        #self.catStore = gtk.ListStore(str)
        self.calendars = {}
        self.categories = {}
        
        self.miscOptions = {}
        
        self.autoSaveExit = False
        
        if os.name == "nt":
            self.confdir = os.environ["APPDATA"]
        elif os.name == "posix":
            self.confdir = os.environ["HOME"]
            self.confdir = os.path.join(self.confdir, ".config")
        self.confdir = os.path.join(self.confdir, "NGCal")
        if not os.access(self.confdir, os.F_OK):
            os.mkdir(self.confdir)
        if not os.access(os.path.join(self.confdir, self.configFile), os.F_OK):
            self.createConfigFile()
        f = open(os.path.join(self.confdir, self.configFile),'ra')
        line = f.readline().strip()
        while line <> '':
            if line[0] <> '#':
                opt = line.split('=')[0]
                val = line.split('=')[1]
               # print val
                self.setOption(opt,val)
            line = f.readline().strip()
        f.close()    
        if self.categories == {}:
            self.makeDefaultCategories()
    def setOption(self, opt, val):
        if opt == "Calendar":
            filename = val.split('|')[0]
            name = val.split('|')[1]
            new_calendar = ogzCalendar().load(filename, name)
            if not new_calendar:
                self.oBase.message("Calendar file : " + filename + " not found.")
            else:    
                self.addCalendar(new_calendar)
        elif opt == "AutoSaveOnExit":
            if val == "True":
                self.autoSaveExit = True
            if val == "False":
                self.autoSaveExit = False
        elif opt == "Categories":
            self.add_categorie(val)
        else:
            self.miscOptions[opt] = val
        
        
    def addCalendar(self, new_calendar):
        self.calendars[new_calendar.filename] = new_calendar
    
    def createConfigFile(self):
        f = open(os.path.join(self.confdir, self.configFile),'wa')
        f.write("# NGCal\n")
        f.write("Calendar=" + os.path.join(self.confdir,"default.ics")+"|Default\n")
        f.write("AutoSaveOnExit=False\n")
        f.close
        ogzCalendar().create(os.path.join(self.confdir,"default.ics"))
        
    def createNewTempCalendar(self):
        newCal = ogzCalendar()
        newCal.filename = "NEWTEMP"
        newCal.name = "New Calendar"
        return newCal
    
    def writeCalendarOnDisk(self, ocal):
        f = open(ocal.filename,'wb')
        f.write(ocal.cal.as_string())
        f.close()

    def writeConfOnDisk(self):
        f = open(os.path.join(self.confdir, self.configFile),'wa')
        f.write("# NGCal\n")
        for ocal in self.calendars.values():
            f.write("Calendar=" + os.path.join(ocal.filename) + "|" + ocal.name + "\n")
        f.write("AutoSaveOnExit=" + str(self.autoSaveExit) + "\n")
        for cat in self.categories.keys():
            f.write("Categories=" + cat + "\n")
        for mo in self.miscOptions.keys():    
            f.write(mo + "=" + str(self.miscOptions[mo]) + "\n")
        f.close
    
    def add_categorie(self, cat):
        print cat
        self.categories[cat] = ogzCategorie(cat)
        self.categories[cat].visible = True
        return self.categories[cat]
    
    def makeDefaultCategories(self):
        for cat in ["Job", "Holiday"]:
            self.add_categorie(cat)
            
    
   # def getCategories(self):
   #     self.catStore.clear()
   #     f = open("./categories",'ra')
   #     line = f.readline().strip()
   #     while line <> '':
   #         if line[0] <> '#':
   #             self.catStore.append(line)
   #         line = f.readline().strip()
            
            
